using System;

namespace serial {

  /// <summary>Command line test program for creating Gpsx files</summary>
  /// <remarks>
  /// Reads lines from stdin in format: latitute longitutde elevation each
  /// double in local fomat. Creates a GPX output describing the path
  /// from the input file.
  /// </remarks>
  /// <example>
  /// Assuming locales requiring a comma as decimal point:
  /// <code>
  /// C:\&gt;type path.txt
  /// 12,1234 49,2345 401,5
  /// 12,1244 49,2355 402,5
  /// 12,1254 49,2365 403,5
  /// 
  /// C:\&gt;gpsx.exe path.gpx &lt; path.txt
  /// 
  /// C:\&gt;type path.gpx
  /// &lt;?xml version="1.0" encoding="utf-8"?&gt;
  /// &lt;gpx xmlns="http://www.topografix.com/GPX/1/0"&gt;
  ///   &lt;time&gt;2008-12-12T11:00:35Z&lt;/time&gt;
  ///   &lt;wpt lat="12.1234" lon="49.2345"&gt;
  ///     &lt;ele&gt;401.5&lt;/ele&gt;
  ///     &lt;time&gt;2008-12-12T11:00:35Z&lt;/time&gt;
  ///     &lt;name&gt;0&lt;/name&gt;
  ///     &lt;desc&gt;0&lt;/desc&gt;
  ///     &lt;sym&gt;Dot&lt;/sym&gt;
  ///     &lt;type&gt;Dot&lt;/type&gt;
  ///   &lt;/wpt&gt;
  ///   &lt;wpt lat="12.1244" lon="49.2355"&gt;
  ///     &lt;ele&gt;402.5&lt;/ele&gt;
  ///     &lt;time&gt;2008-12-12T11:00:35Z&lt;/time&gt;
  ///     &lt;name&gt;1&lt;/name&gt;
  ///     &lt;desc&gt;1&lt;/desc&gt;
  ///     &lt;sym&gt;Dot&lt;/sym&gt;
  ///     &lt;type&gt;Dot&lt;/type&gt;
  ///   &lt;/wpt&gt;
  ///   &lt;wpt lat="12.1254" lon="49.2365"&gt;
  ///     &lt;ele&gt;403.5&lt;/ele&gt;
  ///     &lt;time&gt;2008-12-12T11:00:35Z&lt;/time&gt;
  ///     &lt;name&gt;2&lt;/name&gt;
  ///     &lt;desc&gt;2&lt;/desc&gt;
  ///     &lt;sym&gt;Dot&lt;/sym&gt;
  ///     &lt;type&gt;Dot&lt;/type&gt;
  ///   &lt;/wpt&gt;
  ///   &lt;bounds minlat="12.1234" minlon="49.2345"
  ///              maxlat="12.1254" maxlon="49.2365" /&gt;
  /// &lt;/gpx&gt;
  /// </code>
  /// </example>
  /// <seealso cref="Gpsx">Gpsx</seealso>
  public class GpsxTest {

    /// <summary>The main method</summary>
    /// <param name="args">name of the resulting gpsx file</param>
    public static void Main(string[] args) {
      Gpsx     gpsx;
      string   line;
      string[] sa;
      double   lat, lon, ele;

      gpsx = null;
      try {
        if (args.Length >= 1) {
          gpsx = new Gpsx();
          gpsx.open(args[0]);
          while((line = Console.ReadLine()) != null) {
            lat = 0.0; lon = 0.0; ele = 0.0;
            sa = line.Split();
            if (sa.Length >= 1) lat = double.Parse(sa[0]);
            if (sa.Length >= 2) lon = double.Parse(sa[1]);
            if (sa.Length >= 3) ele = double.Parse(sa[2]);
            gpsx.addLocation(lat, lon, ele);
          }
        }
        else {
          Console.WriteLine("Usage {0} file.gpsx < file.in", Utils.Exepath);
        }
      }
      catch(Exception excp) {
        Console.WriteLine(excp.ToString());
      }
      if (gpsx != null) {
        try { gpsx.close(); } catch(Exception) {}
      }
    } // main()

  } // class UTMTest

} // namespace serial

