using System;
using System.Text;
using System.Text.RegularExpressions;

namespace serial {

  /// <summary>Command line test program for PSRF103 messages</summary>
  /// <remarks>
  /// Creates a SiRF propetiary PSRF103 sequence for controling the
  /// amount and the frequency of the generated NMEA sequences GGA,
  /// GLL, GSA, GSV, RMC and VTG. The sequences generated by this utility
  /// may be sent to the serial port of the GPS chip in order to decrease
  /// the amount of the generated information.
  /// </remarks>
  /// <example>
  /// <code>
  /// psrf103.exe GLL false 0 true
  /// msg=GLL mode=False rate=0 chksumEnable=True psrf=\$PSRF103,01,00,00,01\*25\r\n
  /// 
  /// psrf103.exe GSA false 0 true
  /// msg=GSA mode=False rate=0 chksumEnable=True psrf=\$PSRF103,02,00,00,01\*26\r\n
  /// 
  /// psrf103.exe GSV false 0 true
  /// msg=GSV mode=False rate=0 chksumEnable=True psrf=\$PSRF103,03,00,00,01\*27\r\n
  /// 
  /// psrf103.exe RMC false 0 true
  /// msg=RMC mode=False rate=0 chksumEnable=True psrf=\$PSRF103,04,00,00,01\*20\r\n
  /// </code>
  /// </example>
  /// <seealso cref="Utils.psrf103">Utils.psrf103</seealso>
  public class Psrf103Test {

    /// <summary>The main method</summary>
    /// <param name="args">msg mode rate chksumEnable</param>
    public static void Main(string[] args) {
      string     s;
      byte[]     psrf;
      Psrf103msg msg;
      byte       rate;
      bool       mode, chksumEnable;

      try {
        if (args.Length >= 4) {
          msg = (Psrf103msg) Enum.Parse(typeof(Psrf103msg), args[0], false);
          mode = bool.Parse(args[1]);
          rate = byte.Parse(args[2]);
          chksumEnable = bool.Parse(args[3]);
          psrf = Utils.psrf103(msg, mode, rate, chksumEnable);
          s = Encoding.ASCII.GetString(psrf);
          s = Regex.Escape(s);
          Console.WriteLine("msg={0} mode={1} rate={2} chksumEnable={3} psrf={4}",
                            msg, mode, rate, chksumEnable, s);
        }
        else {
          Console.WriteLine("Usage {0} msg mode rate chksumEnable",
                            Utils.Exepath);
          Console.WriteLine("msg          one of GGA, GLL, GSA, GSV, RMC, VTG");
          Console.WriteLine("mode         true query, false set rate");
          Console.WriteLine("rate         rate in Hz, 0 disable, max 255");
          Console.WriteLine("chksumEnable true enable checksum, false disable");
        }
      }
      catch(Exception excp) {
        Console.WriteLine(excp.ToString());
      }
    } // main()

  } // class UTMTest

} // namespace serial

